from rich.progress import track
from rich.console import Console
from time import sleep
import os

WORK_TIME = 25 * 60
SHORT_BREAK_TIME = 5 * 60
LONG_BREAK_TIME = 30 * 60

console = Console()


class pomody:
    def __init__(self) -> None:

        count = 0
        while True:

            if count != 3:
                os.system("clear")
                self.progress_bar(WORK_TIME, "Working")
                os.system("clear")
                count += 1
                console.print(
                    "Working time has ended, would you like to take a break?: y/n"
                )
                var = input()
                os.system("clear")
                if var == "y":
                    self.progress_bar(SHORT_BREAK_TIME, "Break!")
                    os.system("clear")
                    console.print(
                        "Break has ended, press enter when you are ready to work again"
                    )
                    input()
            else:
                console.print(
                    "Congratulations! You have completed 4 pomodoros, press enter to start long break"
                )
                input()
                self.progress_bar(LONG_BREAK_TIME, "Long Break!")
                count = 0

    def progress_bar(self, time: int, description: str):
        for _ in track(range(time), description=description):
            sleep(1)



import sys
from rich.console import Console
from pomody.pomody import pomody

console = Console()


class main:
    def __init__(self) -> None:
        if "-h" in sys.argv or "--help" in sys.argv:
            console.print(self.help())

        elif "-nm" in sys.argv or "--no-messages" in sys.argv:
            pomody(False)

        else:
            pomody()

    def help(self):
        var = """
            Usage:
                pomody [PARAMETERS]
            
            Parameters:
                -h, --help: Show this help
                -nm --no-messages: Disable messages
                """
        return var


if __name__ == "__main__":
    main()



from distutils.core import setup

setup(
    name="pomody",  # How you named your package folder (MyLib)
    packages=["pomody"],  # Chose the same as "name"
    version="0.5",  # Start with a small number and increase it with every change you make
    license="MIT",  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description="A pomodoro CLI app",  # Give a short description about your library
    author="Teko",  # Type in your name
    author_email="tekofxx@gmail.com",  # Type in your E-Mail
    url="https://github.com/Tekofx/pomody",  # Provide either the link to your github or to your website
    download_url="https://github.com/Tekofx/pomody/archive/refs/tags/",  # I explain this later on
    keywords=[
        "pomodoro",
        "productivity",
        "time",
        "timer",
        "work",
    ],
    install_requires=[
        "rich",
    ],
    classifiers=[
        "Development Status :: 4 - Beta",  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        "Intended Audience :: Developers",  # Define that your audience are developers
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",  # Again, pick a license
        "Programming Language :: Python :: 3",  # Specify which pyhton versions that you want to support
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.8",
    ],
    entry_points={
        "console_scripts": [
            "pomody=pomody.__main__:main",
        ]
    },
)
